@@ -5,9 +5,9 @@ use warnings;
 
 our ($VERSION, $AUTOLOAD);
 
-$VERSION = '0.7';
+$VERSION = '1.01';
 
-sub __new 
+sub __new
 {
     my $class = shift;
 
@@ -20,11 +20,14 @@ sub __new
     $obj->{months}          = \%{$class.'::'.'data_months'};
     $obj->{months_abbrev}   = \%{$class.'::'.'data_months_abbrev'};
     $obj->{months_all}      = \@{$class.'::'.'data_months_all'};
+    $obj->{conversion}      = \%{$class.'::'.'data_conversion'};
+    $obj->{helpers}         = \%{$class.'::'.'data_helpers'};
+    $obj->{duration}        = \%{$class.'::'.'data_duration'};
 
     return bless $obj, ref($class) || $class;
 }
 
-AUTOLOAD 
+AUTOLOAD
 {
     my ($self, $exp) = @_;
 
@@ -57,8 +60,8 @@ DateTime::Format::Natural::Lang::Base - Base class for DateTime::Format::Natural
 
 =head1 DESCRIPTION
 
-The C<DateTime::Format::Natural::Lang::Base> module defines the core functionality for
-C<DateTime::Format::Natural::Lang::> classes.
+The C<DateTime::Format::Natural::Lang::Base> class defines the core functionality for
+C<DateTime::Format::Natural::Lang::> grammar classes.
 
 =head1 SEE ALSO
 
